==> cyberdrop_dl_patched-6.1.1.dev0.tar.gz: cyberdrop_dl_patched-6.1.1.dev0/README.md <==
<div align="center">

# `cyberdrop-dl-patched`
*Bulk asynchronous downloader for multiple file hosts*

[![PyPI - Version](https://img.shields.io/pypi/v/cyberdrop-dl-patched)](https://pypi.org/project/cyberdrop-dl-patched/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/cyberdrop-dl-patched)](https://pypi.org/project/cyberdrop-dl-patched/)
[![Docs](https://img.shields.io/badge/docs-wiki-blue?link=https%3A%2F%2Fscript-ware.gitbook.io%2Fcyberdrop-dl)](https://script-ware.gitbook.io/cyberdrop-dl)
[![GitHub License](https://img.shields.io/github/license/jbsparrow/CyberDropDownloader)](https://github.com/jbsparrow/CyberDropDownloader/blob/master/LICENSE)
[![linting - Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/jbsparrow/CyberDropDownloader/actions/workflows/ruff.yaml)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/cyberdrop-dl-patched)](https://pypistats.org/packages/cyberdrop-dl-patched)

[![Discord](https://discordapp.com/api/guilds/1070206871564197908/widget.png?style=banner2)](https://discord.com/invite/P5nsbKErwy)


Brand new and improved! Cyberdrop-DL now has an updated paint job, fantastic new look. It's now easier to use than ever before!

![Cyberdrop-DL TUI Preview](https://raw.githubusercontent.com/jbsparrow/CyberDropDownloader/refs/heads/master/docs/assets/cyberdrop-dl_tui_preview.png)

</div>

## Supported Sites

See the [list of supported sites](https://script-ware.gitbook.io/cyberdrop-dl/reference/supported-websites) on the official wiki


## Quickstart

Follow the [quickstart guide](https://script-ware.gitbook.io/cyberdrop-dl/quick-start) for instructions on how to install and configure Cyberdrop-DL


## Contributing
If there is a feature you want, you've discovered a bug, or if you have other general feedback, please create an issue for it!

See [CONTRIBUTING.md](https://github.com/jbsparrow/CyberDropDownloader/blob/master/CONTRIBUTING.md) for instructions on [opening an Issue](https://github.com/jbsparrow/CyberDropDownloader/blob/master/CONTRIBUTING.md#submitting-an-issue). If you want to submit code to the project, follow the [guidelines on how to contribute](https://github.com/jbsparrow/CyberDropDownloader/blob/master/CONTRIBUTING.md#submitting-a-pull-request-pr).

==> cyberdrop_dl_patched-6.7.0.tar.gz: cyberdrop_dl_patched-6.7.0/README.md <==
<div align="center">

# `cyberdrop-dl-patched`
*Bulk asynchronous downloader for multiple file hosts*

[![PyPI - Version](https://img.shields.io/pypi/v/cyberdrop-dl-patched)](https://pypi.org/project/cyberdrop-dl-patched/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/cyberdrop-dl-patched)](https://pypi.org/project/cyberdrop-dl-patched/)
[![Docs](https://img.shields.io/badge/docs-wiki-blue?link=https%3A%2F%2Fscript-ware.gitbook.io%2Fcyberdrop-dl)](https://script-ware.gitbook.io/cyberdrop-dl)
[![GitHub License](https://img.shields.io/github/license/jbsparrow/CyberDropDownloader)](https://github.com/jbsparrow/CyberDropDownloader/blob/master/LICENSE)
[![linting - Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/jbsparrow/CyberDropDownloader/actions/workflows/ruff.yaml)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/cyberdrop-dl-patched)](https://pypistats.org/packages/cyberdrop-dl-patched)

[![Discord](https://discordapp.com/api/guilds/1070206871564197908/widget.png?style=banner2)](https://discord.com/invite/P5nsbKErwy)


Brand new and improved! Cyberdrop-DL now has an updated paint job, fantastic new look. It's now easier to use than ever before!

![Cyberdrop-DL TUI Preview](https://raw.githubusercontent.com/jbsparrow/CyberDropDownloader/refs/heads/master/docs/assets/cyberdrop-dl_tui_preview.png)

</div>

## Supported Sites

See the [list of supported sites](https://script-ware.gitbook.io/cyberdrop-dl/reference/supported-websites) on the official wiki


## Getting Started

Follow the [getting-started guide](https://script-ware.gitbook.io/cyberdrop-dl/getting-started) for instructions on how to install and configure Cyberdrop-DL


## Contributing
If there is a feature you want, you've discovered a bug, or if you have other general feedback, please create an issue for it!

See [CONTRIBUTING.md](https://github.com/jbsparrow/CyberDropDownloader/blob/master/CONTRIBUTING.md) for instructions on [opening an Issue](https://github.com/jbsparrow/CyberDropDownloader/blob/master/CONTRIBUTING.md#submitting-an-issue). If you want to submit code to the project, follow the [guidelines on how to contribute](https://github.com/jbsparrow/CyberDropDownloader/blob/master/CONTRIBUTING.md#submitting-a-pull-request-pr).
